# -*- coding: utf-8 -*-
#
"""Univention Configuration Registry output filters."""
#  main configuration registry classes
#
# Copyright 2004-2015 Univention GmbH
#
# http://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

from pipes import quote as escape_value
from univention.config_registry.misc import key_shell_escape

__all__ = ['Output', 'filter_shell', 'filter_keys_only', 'filter_sort']


class Output:
	"""Output buffer for applying filter."""
	def __init__(self):
		self.text = []

	def write(self, line):
		"""Append singe line."""
		if line and line.strip():
			self.text.append(line)

	def writelines(self, lines):
		"""Append multiple lines."""
		for line in lines:
			self.text.append(line)


def filter_shell(args, text):  # pylint: disable-msg=W0613
	"""Filter output for shell: escape keys."""
	out = []
	for line in text:
		try:
			var, value = line.split(': ', 1)
		except ValueError:
			var = line
			value = ''
		out.append('%s=%s' % (key_shell_escape(var), escape_value(value)))
	return out


def filter_keys_only(args, text):  # pylint: disable-msg=W0613
	"""Filter output: strip values."""
	out = []
	for line in text:
		out.append(line.split(': ', 1)[0])
	return out


def filter_sort(args, text):  # pylint: disable-msg=W0613
	"""Filter output: sort by key."""
	text.sort()
	return text


# vim:set sw=4 ts=4 noet:
